import {Image, ScrollView, View } from "@tarojs/components"
import Popup from "@/components/popup"
import classnames from "classnames";
import LoadingCard from "@/components/loadingCard";
import InfiniteScroll from "@/components/infiniteScroll";
import styles from "./index.module.scss"
import { useEffect, useState } from "react";
import Taro from "@tarojs/taro";
import Search from "@/components/search";
import Counter from "../counter";

type param = {
    show?: true|false,
    onClose?: () => void
}
export default ({show = false, onClose}: param) => {
    const selectList = ['剪板', '散剪', '大货']
    const [selectIndex, setSelectIndex] = useState(0)
    const selectProduct = (index:number) => {
        setSelectIndex(index)
    }

    const [list, setList] = useState<any[]>([])
    const [loading, setLoading] = useState(false)

    useEffect(() => {
        let lists:any[] = []
        for(let i = 0; i < 20; i++) {
            lists = [...lists, {
                title:`${i}#薄荷绿`,
                subtitle: '0770# 21S单面平纹(食毛)',
                tag: '剪板',
                select: i%2?true: false
            }]
        }
        setList([...lists])
    }, [])

    const [showPopup, setShowPopup] = useState(false)
    useEffect(() => {
        setShowPopup(show)
    }, [show])


    //popup关闭
    const closePopup = () => {
        onClose?.()
        setShowPopup(false)
    }

    //已选择提示
    const [selectCountMsg, setSelectCountMsg] = useState('')
    useEffect(() => {
        if(selectIndex == 2) {
            setSelectCountMsg(`当前已选${1}种，共${1}米`)
        } else {
            setSelectCountMsg(`当前已选${1}种，共${1}条`)
        }
    },[selectIndex])
    
    return (
        <View className={styles.shop_cart_main}>
            <Popup showTitle={false} show={showPopup} onClose={() => closePopup()}>
                <View className={styles.popup_con}>
                    <View className={styles.header}>0770# 21S单面平纹(食毛)</View>
                    <View className={styles.search}>
                        <View className={styles.search_title}>下单类型:</View>
                        <View className={styles.search_list}>
                            {selectList.map((item, index) => {
                                return <View key={index} onClick={() => selectProduct(index)} className={classnames(styles.search_item, (selectIndex==index)&&styles.search_item_select)}>{item}</View>
                            })}
                        </View>
                    </View>
                    <View className={styles.colorFind}>
                        <Search placeIcon="out" showBtn={true}/>
                    </View>
                    <View className={styles.colorNum}>
                        <View className={styles.title}>颜色分类 (13)</View>
                        <View className={classnames('iconfont icon-sousuo', styles.miconfont)}></View>
                    </View>
                    <View className={styles.product_color_con}>
                        <InfiniteScroll>
                            <View className={styles.color_con}>
                                {new Array(10).fill('').map(item => {
                                    return <View className={styles.item}>
                                        <View className={styles.item_color}>
                                            <Image src='https://gimg2.baidu.com/image_search/src=http%3A%2F%2Fimg.jj20.com%2Fup%2Fallimg%2F811%2F021315104H2%2F150213104H2-3-1200.jpg&refer=http%3A%2F%2Fimg.jj20.com&app=2002&size=f9999,10000&q=a80&n=0&g=0n&fmt=auto?sec=1651817947&t=5467a207f845ddfc7737d55934e6b26d'/>
                                        </View>
                                        <View className={styles.item_con}>
                                            <View className={styles.title}>1#薄荷绿</View>
                                            <View className={styles.num}>¥25.5/m</View>
                                        </View>
                                        <View className={styles.btn_con}>
                                            {/* <View className={styles.btn}>添加</View> */}
                                            <View className={styles.btn_count}>
                                                <Counter/>
                                            </View>
                                        </View>
                                    </View>
                                })}
                            </View>
                        </InfiniteScroll>
                    </View>
                    <View className={styles.buy_btn}>
                        <View className={styles.buy_btn_con}>
                            <View className={styles.count}>{selectCountMsg}</View>
                            <View className={styles.add_cart}>加入购物车</View>
                        </View>
                    </View>
                </View>
                <View className="common_safe_area_y"></View>
            </Popup>
        </View>
    )
}